@@ -7,24 +7,33 @@ from .shortcuts import get_perm_queryset
 class PermMixin(object):
     perm = None
 
+    def has_perm(self, object_or_model=None):
+        if self.perm:
+            return False
+        return True
+
 
 class PermSingleObjectMixin(PermMixin):
+
     def dispatch(self, request, *args, **kwargs):
         if isinstance(self, CreateView):
-            obj = self.model
-            if self.perm and not self.request.user.has_perm(self.perm, obj):
+            if not self.has_perm(self.model):
                 raise PermissionDenied()
         return super(PermSingleObjectMixin, self).dispatch(request, *args, **kwargs)
 
     def get_object(self, *args, **kwargs):
-        if isinstance(self, CreateView):
-            obj = self.model
-        else:
-            obj = super(PermSingleObjectMixin, self).get_object(*args, **kwargs)
-        if self.perm and not self.request.user.has_perm(self.perm, obj):
+        obj = super(PermSingleObjectMixin, self).get_object(*args, **kwargs)
+        if not self.has_perm(obj):
             raise PermissionDenied()
         return obj
 
+    def has_perm(self, object_or_model=None):
+        if self.perm:
+            if not object_or_model:
+                object_or_model = self.get_object_or_model_for_permission()
+            return self.request.user.has_perm(self.perm, object_or_model)
+        return True
+
 
 class PermMultipleObjectMixin(PermMixin):
     def get_queryset(self, *args, **kwargs):
